Axes3D automatically adding self to Figure is deprecated
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

New `.Axes3D` objects previously added themselves to figures when they
were created, unlike all other Axes classes, which lead to them being
added twice if ``fig.add_subplot(111, projection='3d')`` was called.

This behavior is now deprecated and will warn.  The new keyword argument
*auto_add_to_figure* controls the behavior and can be used to suppress the
warning.  The default value will change to False in mpl3.5, and any
non-False value will be an error in mpl3.6.

In the future, `.Axes3D` will need to be explicitly added to the
figure ::

  fig = Figure()
  # create Axes3D
  ax = Axes3d(fig)
  # add to Figure
  fig.add_axes(ax)

as needs to be done for other `.axes.Axes` sub-classes. Or, a 3-d 
projection can be made via::

    fig.add_subplot(projection='3d')
